Find class

Constructors

Find({int? allowChildren, int? expandable, int? leaf, String? id, String? text, Object? context})
Returns a new Find instance.

Properties

allowChildren ↔ int?
Minimum value: 0 Maximum value: 1
getter/setter pair
context ↔ Object?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
expandable ↔ int?
Minimum value: 0 Maximum value: 1
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
leaf ↔ int?
Minimum value: 0 Maximum value: 1
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Find?
Returns a new Find instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<Find>?
mapFromJson(dynamic json) → Map<String, Find>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<Find>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.