GraphiteFunction class

Constructors

GraphiteFunction({required String name, required List<FunctionArgument> arguments})
GraphiteFunction.fromJson(Map<String, dynamic> json)
factory

Properties

arguments List<FunctionArgument>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGraphiteQuery() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited