MetricsApi class

Constructors

MetricsApi([ApiClient? apiClient])

Properties

apiClient → ApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

find(String query) → Future<List<Find>?>
Find a metric
findWithHttpInfo(String query) → Future<Response>
Find a metric
index() → Future<List<String>?>
Lists all the metrics
indexWithHttpInfo() → Future<Response>
Lists all the metrics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited