RenderApi class

Constructors

RenderApi([ApiClient? apiClient])

Properties

apiClient → ApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Map<String, dynamic> request) → Future<List<TimeSeries>?>
Timeseries values
renderWithHttpInfo(List<String> target, {String? from, String? until, int? maxDataPoints}) → Future<Response>
Timeseries values
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited